@@ -27,7 +27,8 @@ class Applications(Resource):
         :param page: Pagination index
 
         :rtype: dict
-        :return: The JSON response of the API
+        :return: The JSON response of the API, with an additional 'pages' key
+            if there are paginated results
 
         ::
 
@@ -71,7 +72,17 @@ class Applications(Resource):
                             ]
                         }
                     }
-                ]
+                ],
+                "pages": {
+                    "last": {
+                        "url": "https://api.newrelic.com/v2/applications.json?page=2",
+                        "rel": "last"
+                    },
+                    "next": {
+                        "url": "https://api.newrelic.com/v2/applications.json?page=2",
+                        "rel": "next"
+                    }
+                }
             }
 
         """
@@ -317,16 +328,29 @@ class Applications(Resource):
         :param page: Pagination index
 
         :rtype: dict
-        :return: The JSON response of the API
+        :return: The JSON response of the API, with an additional 'pages' key
+            if there are paginated results
 
         ::
 
             {
-                "metric": {
-                    "name": "string",
-                    "values": [
-                        "string"
-                    ]
+                "metrics": [
+                    {
+                        "name": "string",
+                        "values": [
+                            "string"
+                        ]
+                    }
+                ],
+                "pages": {
+                    "last": {
+                        "url": "https://api.newrelic.com/v2/applications/{application_id}/metrics.json?page=2",
+                        "rel": "last"
+                    },
+                    "next": {
+                        "url": "https://api.newrelic.com/v2/applications/{application_id}/metrics.json?page=2",
+                        "rel": "next"
+                    }
                 }
             }
 
