@@ -26,7 +26,8 @@ class Components(Resource):
         :param page: Pagination index
 
         :rtype: dict
-        :return: The JSON response of the API
+        :return: The JSON response of the API, with an additional 'pages' key
+            if there are paginated results
 
         ::
 
@@ -52,7 +53,17 @@ class Components(Resource):
                             }
                         ]
                     }
-                ]
+                ],
+                "pages": {
+                    "last": {
+                        "url": "https://api.newrelic.com/v2/components.json?page=2",
+                        "rel": "last"
+                    },
+                    "next": {
+                        "url": "https://api.newrelic.com/v2/components.json?page=2",
+                        "rel": "next"
+                    }
+                }
             }
 
         """
@@ -130,11 +141,23 @@ class Components(Resource):
         ::
 
             {
-                "metric": {
-                    "name": "string",
-                    "values": [
-                        "string"
-                    ]
+                "metrics": [
+                    {
+                        "name": "string",
+                        "values": [
+                            "string"
+                        ]
+                    }
+                ],
+                "pages": {
+                    "last": {
+                        "url": "https://api.newrelic.com/v2/components/{component_id}/metrics.json?page=2",
+                        "rel": "last"
+                    },
+                    "next": {
+                        "url": "https://api.newrelic.com/v2/components/{component_id}/metrics.json?page=2",
+                        "rel": "next"
+                    }
                 }
             }
 
